==> dumble-0.8.4.tar.gz: lib/dumble.dart <==
/*
TODO:
ACL Stuff
Plugin data transmission
*/

/// A Mumble transport client framework
library dumble;

export 'src/audio/audio_client.dart'
    show AudioClient, AudioFrame, AudioFrameSink, AudioErrorCallback;
export 'src/audio/audio_packet.dart' show IncomingAudioPacket;
export 'src/model/audio.dart'
    show PositionalInformation, normalTalking, AudioCodec, TalkMode;
export 'src/model/ban.dart' show BanEntry;
export 'src/model/channel.dart' show Channel, ChannelChanges;
export 'src/model/crypto.dart' show NonceOutOfSyncException, CryptState;
export 'src/model/exceptions.dart'
    show PermissionDeniedException, RejectException, DenyType, RejectType;
export 'src/model/permission.dart' show Permission;
export 'src/model/registered_user.dart' show RegisteredUser;
export 'src/model/server_infos.dart'
    show
        ServerCodecVersion,
        ServerConfig,
        ServerConnectionStats,
        ServerSuggestedClientConfig;
export 'src/model/stats.dart' show PacketStats, PingStats, VersionInformation;
export 'src/model/text_message.dart'
    show IncomingTextMessage, OutgoingTextMessage, TextMessage;
export 'src/model/user_stats.dart' show UserStats;
export 'src/model/user.dart' show Self, User, UserChanges;
export 'src/model/voice_target.dart' show VoiceTarget;
export 'src/client.dart'
    show MumbleClient, ServerInfo, rootChannelId, CryptStateProvider;
export 'src/connection_options.dart' show ConnectionOptions;
export 'src/connection.dart' show OnBadCertificate;
export 'src/listeners.dart'
    show
        AudioListener,
        ChannelListener,
        MumbleClientListener,
        Notifier,
        UserListener;

==> dumble-0.8.9.tar.gz: lib/dumble.dart <==
/*
TODO:
ACL Stuff
Plugin data transmission
*/

/// A Mumble transport client framework
library dumble;

export 'src/audio/audio_client.dart'
    show AudioClient, AudioFrame, AudioFrameSink, AudioErrorCallback;
export 'src/audio/audio_packet.dart' show IncomingAudioPacket;
export 'src/model/audio.dart'
    show PositionalInformation, normalTalking, AudioCodec, TalkMode;
export 'src/model/ban.dart' show BanEntry;
export 'src/model/channel.dart' show Channel, ChannelChanges;
export 'src/model/crypto.dart' show NonceOutOfSyncException, CryptState;
export 'src/model/model_exceptions.dart'
    show PermissionDeniedException, RejectException, DenyType, RejectType;
export 'src/model/permission.dart' show Permission;
export 'src/model/registered_user.dart' show RegisteredUser;
export 'src/model/server_infos.dart'
    show
        ServerCodecVersion,
        ServerConfig,
        ServerConnectionStats,
        ServerSuggestedClientConfig;
export 'src/model/stats.dart' show PacketStats, PingStats, VersionInformation;
export 'src/model/text_message.dart'
    show IncomingTextMessage, OutgoingTextMessage, TextMessage;
export 'src/model/user_stats.dart' show UserStats;
export 'src/model/user.dart' show Self, User, UserChanges;
export 'src/model/voice_target.dart' show VoiceTarget;
export 'src/client.dart'
    show MumbleClient, ServerInfo, rootChannelId, CryptStateProvider;
export 'src/connection_options.dart' show ConnectionOptions;
export 'src/connection.dart' show OnBadCertificate;
export 'src/listeners.dart'
    show
        AudioListener,
        ChannelListener,
        MumbleClientListener,
        Notifier,
        UserListener;
export 'src/exceptions.dart' show ProtocolException, UnhandeledError;
